# Basic example using a one between-subject factor design with the data in compiled format.
# Ficticious data present success or failure of observation classified according
# to the state of residency (three levels); 175 participants have been observed in total.
# The cells are unequal:
minimalBSExample
# First, perform the omnibus analysis :
w <- anopa( {s;n} ~ state, minimalBSExample)
summary(w)
# Compare the first two states jointly to the third, and
# compare the first to the second state:
cw <- contrastProportions( w, list(
contrast1 = c(1, 1, -2)/2,
contrast2 = c(1, -1, 0) )
)
summary(cw)
Run the code above in your browser using DataLab