View source: R/ANOPA-unitaryAlpha.R
| unitaryAlpha | R Documentation |
The function unitaryAlpha() computes
the unitary alpha (\insertCitelc23ANOPA). This
quantity is a novel way to compute correlation in a matrix
where each column is a measure and each line, a subject.
This measure is based on Cronbach's alpha (which could be
labeled a 'global alpha').
unitaryAlpha( m )
m |
A data matrix for a group of observations. |
This measure is derived from Cronbach's measure of reliability as shown by \insertCitelc23;textualANOPA.
A measure of correlation between -1 and +1.
# Generate a random matrix (here binary entries)
set.seed(42)
N <- M <- 10
m <- matrix( runif(N*M), N, M)
# compute the unitary alpha from that random matrix
unitaryAlpha(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.