The function 'unitaryAlpha()' computes
the unitary alpha (lc23ANOPA). This
quantity is a novel way to compute correlation in a matrix
where each column is a measure and each line, a subject.
This measure is based on Cronbach's alpha (which could be
labeled a 'global alpha').
Usage
unitaryAlpha( m )
Value
A measure of correlation between -1 and +1.
Arguments
m
A data matrix for a group of observations.
Details
This measure is derived from Cronbach' measure of
reliability as shown by lc23;textualANOPA.
# Generate a random matrix (here binary entries)set.seed(42)
N <- M <- 10
m <- matrix( runif(N*M), N, M)
# compute the unitary alpha from that random matrixunitaryAlpha(m)